grap
====

`grap` is a PEG parser for Python.


Links
-----

* [Repository](https://github.com/phoenixr-codes/grap)
* [PyPI](https://pypi.org/project/grap)
* [Documentation](https://phoenixr-codes.github.io/grap)


TODO
----

* [ ] rename action to marker?
* [ ] add fn make_rule to create a rule from tree
* [ ] warn when rule is used without parens (class instead of obj)
* [ ] add visualizer that shows pointer while parsing
* [ ] Pygments for grap lang
